Learn R Programming

sulcimap (version 1.0.6)

get_assets_light: Lightweight assets for light example Unzips a tiny assets bundle and returns the directory path.

Description

Lightweight assets for light example Unzips a tiny assets bundle and returns the directory path.

Usage

get_assets_light()

Arguments

Value

A character scalar: path to the unzipped assets directory.